[![Build Status](https://travis-ci.org/MartinThoma/memtop.svg?branch=master)](https://travis-ci.org/MartinThoma/memtop)
[![Coverage Status](https://img.shields.io/coveralls/MartinThoma/memtop.svg)](https://coveralls.io/r/MartinThoma/memtop?branch=master)
[![Documentation Status](http://img.shields.io/badge/docs-latest-brightgreen.svg)](http://pythonhosted.org/memtop)
[![Code Health](https://landscape.io/github/MartinThoma/memtop/master/landscape.svg)](https://landscape.io/github/MartinThoma/memtop/master)

# memtop
View memory consumption
